pub struct VideoCompositorInput {
pub sink: Box<dyn Sink>,
pub layer: VideoLayerHandle,
}Expand description
The two endpoints created for one compositor input registration.
Move sink into the upstream pipeline and retain layer in application
code for runtime placement changes.
Fields
sink: Box<dyn Sink>layer: VideoLayerHandleAuto Trait Implementations
impl !RefUnwindSafe for VideoCompositorInput
impl !Sync for VideoCompositorInput
impl !UnwindSafe for VideoCompositorInput
impl Freeze for VideoCompositorInput
impl Send for VideoCompositorInput
impl Unpin for VideoCompositorInput
impl UnsafeUnpin for VideoCompositorInput