pub struct VideoRect {
pub x: i32,
pub y: i32,
pub width: u32,
pub height: u32,
}Expand description
An output-space rectangle. Signed coordinates allow a layer to be moved partially outside the canvas while its size remains positive.
Fields
x: i32y: i32width: u32height: u32Implementations